@@ -1121,6 +1121,50 @@ class Test:
         self.expect(lambda: regex.search(r"123(?<!a\d+)", "b123").span(),
           "(1, 4)")
 
+        self.expect(lambda: type(regex.match("(a)b(?<=b)(c)", "abc")),
+          self.MATCH_CLASS)
+        self.expect(lambda: regex.match("(a)b(?<=c)(c)", "abc"), "None")
+        self.expect(lambda: type(regex.match("(a)b(?=c)(c)", "abc")),
+          self.MATCH_CLASS)
+        self.expect(lambda: regex.match("(a)b(?=b)(c)", "abc"), "None")
+
+
+        self.expect(lambda: regex.match("(?:(a)|(x))b(?<=(?(2)x|c))c", "abc"),
+          "None")
+        self.expect(lambda: regex.match("(?:(a)|(x))b(?<=(?(2)b|x))c", "abc"),
+          "None")
+        self.expect(lambda: type(regex.match("(?:(a)|(x))b(?<=(?(2)x|b))c",
+          "abc")), self.MATCH_CLASS)
+        self.expect(lambda: regex.match("(?:(a)|(x))b(?<=(?(1)c|x))c", "abc"),
+          "None")
+        self.expect(lambda: type(regex.match("(?:(a)|(x))b(?<=(?(1)b|x))c",
+          "abc")), self.MATCH_CLASS)
+
+        self.expect(lambda: type(regex.match("(?:(a)|(x))b(?=(?(2)x|c))c",
+          "abc")), self.MATCH_CLASS)
+        self.expect(lambda: regex.match("(?:(a)|(x))b(?=(?(2)c|x))c", "abc"),
+          "None")
+        self.expect(lambda: type(regex.match("(?:(a)|(x))b(?=(?(2)x|c))c",
+          "abc")), self.MATCH_CLASS)
+        self.expect(lambda: regex.match("(?:(a)|(x))b(?=(?(1)b|x))c", "abc"),
+          "None")
+        self.expect(lambda: type(regex.match("(?:(a)|(x))b(?=(?(1)c|x))c",
+          "abc")), self.MATCH_CLASS)
+
+        self.expect(lambda: regex.match("(a)b(?<=(?(2)x|c))(c)", "abc"), "None")
+        self.expect(lambda: regex.match("(a)b(?<=(?(2)b|x))(c)", "abc"), "None")
+        self.expect(lambda: regex.match("(a)b(?<=(?(1)c|x))(c)", "abc"), "None")
+        self.expect(lambda: type(regex.match("(a)b(?<=(?(1)b|x))(c)", "abc")),
+          self.MATCH_CLASS)
+
+        self.expect(lambda: type(regex.match("(a)b(?=(?(2)x|c))(c)", "abc")),
+          self.MATCH_CLASS)
+        self.expect(lambda: regex.match("(a)b(?=(?(2)b|x))(c)", "abc"), "None")
+        self.expect(lambda: type(regex.match("(a)b(?=(?(1)c|x))(c)", "abc")),
+          self.MATCH_CLASS)
+
+        self.expect(lambda: type(regex.compile(r"(a)\2(b)")), self.PATTERN_CLASS)
+
     def test_unmatched_in_sub(self):
         # Issue 1519638.
         self.expect(lambda: regex.sub(r"(x)?(y)?", r"\2-\1", "xy"), "'y-x'")
